@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2019  The Software Heritage developers
+# Copyright (C) 2015-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -16,11 +16,10 @@ import docutils.parsers.rst
 import docutils.utils
 
 from rest_framework.decorators import api_view
-import sentry_sdk
 
-from swh.web.common.utils import parse_rst
+from swh.web.api.apiresponse import make_api_response
 from swh.web.api.apiurls import APIUrls
-from swh.web.api.apiresponse import make_api_response, error_response
+from swh.web.common.utils import parse_rst
 
 
 class _HTTPDomainDocVisitor(docutils.nodes.NodeVisitor):
@@ -94,7 +93,7 @@ class _HTTPDomainDocVisitor(docutils.nodes.NodeVisitor):
         subs_made = 1
         while subs_made:
             (par, subs_made) = re.subn(r"(:http:.*)(\[.*\])", r"\1", par)
-        par = par.replace("//", "/")
+        par = re.sub(r"([^:])//", r"\1/", par)
         # transform references to api endpoints doc into valid rst links
         par = re.sub(":http:get:`([^,`]*)`", r"`\1 <\1doc/>`_", par)
         # transform references to some elements into bold text
@@ -212,9 +211,10 @@ class _HTTPDomainDocVisitor(docutils.nodes.NodeVisitor):
         # literal block in endpoint description
         if not self.field_list_visited:
             self.data["description"] += ":\n\n%s\n" % textwrap.indent(text, "\t")
-        # extract example url
+        # extract example urls
         if ":swh_web_api:" in text:
-            self.data["examples"].append("/api/1/" + re.sub(".*`(.*)`.*", r"\1", text))
+            examples_str = re.sub(".*`(.+)`.*", r"/api/1/\1", text)
+            self.data["examples"] += examples_str.split("\n")
 
     def visit_bullet_list(self, node):
         # bullet list in endpoint description
@@ -286,12 +286,7 @@ class APIDocException(Exception):
 
 
 def api_doc(
-    route: str,
-    noargs: bool = False,
-    need_params: bool = False,
-    tags: List[str] = [],
-    handle_response: bool = False,
-    api_version: str = "1",
+    route: str, noargs: bool = False, tags: List[str] = [], api_version: str = "1",
 ):
     """
     Decorator for an API endpoint implementation used to generate a dedicated
@@ -305,18 +300,11 @@ def api_doc(
         noargs: set to True if the route has no arguments, and its
             result should be displayed anytime its documentation
             is requested. Default to False
-        need_params: specify the route requires query parameters
-            otherwise errors will occur. It enables to avoid displaying the
-            invalid response in its HTML documentation. Default to False.
         tags: Further information on api endpoints. Two values are
             possibly expected:
 
                 * hidden: remove the entry points from the listing
                 * upcoming: display the entry point but it is not followable
-
-        handle_response: indicate if the decorated function takes
-            care of creating the HTTP response or delegates that task to the
-            apiresponse module
         api_version: api version string
     """
 
@@ -353,24 +341,11 @@ def api_doc(
         @wraps(f)
         def documented_view(request, **kwargs):
             doc_data = get_doc_data(f, route, noargs)
-
             try:
-                response = f(request, **kwargs)
+                return {"data": f(request, **kwargs), "doc_data": doc_data}
             except Exception as exc:
-                sentry_sdk.capture_exception(exc)
-                if (
-                    request.accepted_media_type == "text/html"
-                    and need_params
-                    and not request.query_params
-                ):
-                    response = None
-                else:
-                    return error_response(request, exc, doc_data)
-
-            if handle_response:
-                return response
-            else:
-                return make_api_response(request, response, doc_data)
+                exc.doc_data = doc_data
+                raise exc
 
         return documented_view
 
