@@ -4,6 +4,7 @@
 # See top-level LICENSE file for more information
 
 import json
+import logging
 import traceback
 from typing import Any, Dict, Optional
 
@@ -11,6 +12,7 @@ import sentry_sdk
 
 from django.http import HttpResponse
 from django.shortcuts import render
+from django.utils.cache import add_never_cache_headers
 from django.utils.html import escape
 from rest_framework.exceptions import APIException
 from rest_framework.request import Request
@@ -23,6 +25,8 @@ from swh.web.common.exc import BadInputExc, ForbiddenExc, LargePayloadExc, NotFo
 from swh.web.common.utils import gen_path_info, shorten_path
 from swh.web.config import get_config
 
+logger = logging.getLogger("django")
+
 
 def compute_link_header(rv: Dict[str, Any], options: Dict[str, Any]) -> Dict[str, Any]:
     """Add Link header in returned value results.
@@ -133,7 +137,7 @@ def make_api_response(
     # and render the apidoc HTML template
     if request.accepted_media_type == "text/html":
         doc_data["response_data"] = data
-        if data:
+        if data is not None:
             doc_data["response_data"] = json.dumps(
                 data, cls=JSONEncoder, sort_keys=True, indent=4, separators=(",", ": ")
             )
@@ -148,20 +152,25 @@ def make_api_response(
             if not doc_data["noargs"]:
                 doc_data["endpoint_path"][-1]["path"] += "/doc/"
 
-        return render(
+        response = render(
             request, "api/apidoc.html", doc_data, status=doc_data["status_code"]
         )
 
     # otherwise simply return the raw data and let DRF picks
     # the correct renderer (JSON or YAML)
     else:
-        return Response(
+        response = Response(
             data,
             headers=headers,
             content_type=request.accepted_media_type,
             status=doc_data["status_code"],
         )
 
+    if getattr(request, "never_cache", False):
+        add_never_cache_headers(response)
+
+    return response
+
 
 def error_response(
     request: Request, exception: Exception, doc_data: Dict[str, Any]
@@ -201,6 +210,7 @@ def error_response(
 
     if get_config()["debug"]:
         error_data["traceback"] = traceback.format_exc()
+        logger.debug(error_data["traceback"])
 
     return make_api_response(request, error_data, doc_data, options=error_opts)
 
