@@ -622,9 +622,26 @@ _accepted_save_requests_gauge = Gauge(
 )
 
 
+# Metric on the delay of save code now request per status and visit_type. This is the
+# time difference between the save code now is requested and the time it got ingested.
+ACCEPTED_SAVE_REQUESTS_DELAY_METRIC = "swh_web_save_requests_delay_seconds"
+
+_accepted_save_requests_delay_gauge = Gauge(
+    name=ACCEPTED_SAVE_REQUESTS_DELAY_METRIC,
+    documentation="Save Requests Duration",
+    labelnames=["load_task_status", "visit_type"],
+    registry=SWH_WEB_METRICS_REGISTRY,
+)
+
+
 def compute_save_requests_metrics() -> None:
-    """Compute a couple of Prometheus metrics related to
-    origin save requests"""
+    """Compute Prometheus metrics related to origin save requests:
+
+    - Number of submitted origin save requests
+    - Number of accepted origin save requests
+    - Save Code Now requests delay between request time and actual time of ingestion
+
+    """
 
     request_statuses = (
         SAVE_REQUEST_ACCEPTED,
@@ -653,6 +670,14 @@ def compute_save_requests_metrics() -> None:
     for labels in labels_set:
         _accepted_save_requests_gauge.labels(*labels).set(0)
 
+    duration_load_task_statuses = (
+        SAVE_TASK_FAILED,
+        SAVE_TASK_SUCCEEDED,
+    )
+
+    for labels in product(duration_load_task_statuses, visit_types):
+        _accepted_save_requests_delay_gauge.labels(*labels).set(0)
+
     for sor in SaveOriginRequest.objects.all():
         if sor.status == SAVE_REQUEST_ACCEPTED:
             _accepted_save_requests_gauge.labels(
@@ -662,3 +687,13 @@ def compute_save_requests_metrics() -> None:
         _submitted_save_requests_gauge.labels(
             status=sor.status, visit_type=sor.visit_type
         ).inc()
+
+        if (
+            sor.loading_task_status in (SAVE_TASK_SUCCEEDED, SAVE_TASK_FAILED)
+            and sor.visit_date is not None
+            and sor.request_date is not None
+        ):
+            delay = sor.visit_date.timestamp() - sor.request_date.timestamp()
+            _accepted_save_requests_delay_gauge.labels(
+                load_task_status=sor.loading_task_status, visit_type=sor.visit_type
+            ).inc(delay)
