@@ -7,7 +7,7 @@ import random
 
 from hypothesis import given
 
-from swh.web.api.utils import enrich_directory
+from swh.web.api.utils import enrich_directory_entry
 from swh.web.common.utils import reverse
 from swh.web.tests.data import random_sha1
 from swh.web.tests.strategies import directory
@@ -22,7 +22,7 @@ def test_api_directory(api_client, archive_data, directory):
 
     dir_content = list(archive_data.directory_ls(directory))
     expected_data = list(
-        map(enrich_directory, dir_content, [rv.wsgi_request] * len(dir_content))
+        map(enrich_directory_entry, dir_content, [rv.wsgi_request] * len(dir_content))
     )
 
     assert rv.data == expected_data
@@ -43,13 +43,13 @@ def test_api_directory_not_found(api_client):
 def test_api_directory_with_path_found(api_client, archive_data, directory):
 
     directory_content = archive_data.directory_ls(directory)
-    path = random.choice(directory_content)
+    dir_entry = random.choice(directory_content)
 
     url = reverse(
-        "api-1-directory", url_args={"sha1_git": directory, "path": path["name"]}
+        "api-1-directory", url_args={"sha1_git": directory, "path": dir_entry["name"]}
     )
     rv = check_api_get_responses(api_client, url, status_code=200)
-    assert rv.data == enrich_directory(path, rv.wsgi_request)
+    assert rv.data == enrich_directory_entry(dir_entry, rv.wsgi_request)
 
 
 @given(directory())
@@ -58,11 +58,12 @@ def test_api_directory_with_path_not_found(api_client, directory):
     path = "some/path/to/nonexistent/dir/"
     url = reverse("api-1-directory", url_args={"sha1_git": directory, "path": path})
     rv = check_api_get_responses(api_client, url, status_code=404)
+    reason = (
+        f"Directory entry with path {path} from root directory {directory} not found"
+    )
     assert rv.data == {
         "exception": "NotFoundExc",
-        "reason": (
-            "Directory entry with path %s from %s not found" % (path, directory)
-        ),
+        "reason": reason,
     }
 
 
